#ifndef SC7A20X_H_
#define SC7A20X_H_

/***********************************************************
* Local define
***********************************************************/
#define SC7A20H_DEVICE_ADDR    0x19
#define SC7A20H_MULTI_READ_FLG  0x80

#define SC7A20H_REG_CTRL4       0x23
#define SC7A20H_REG_CTRL5       0x24
#define SC7A20H_REG_CTRL6       0x25
#define SC7A20H_REG_FIFO_CTRL   0x2E
#define SC7A20H_REG_OUTPUT      0x28
#define SC7A20H_REG_FIFO_SRC    0x2F
#define SC7A20H_REG_INT1        0x30
#define SC7A20H_REG_INT1_SRC    0x31
#define SC7A20H_REG_INT1_THS    0x32
#define SC7A20H_REG_INT1_DUR    0x33
#define SC7A20H_REG_CLICK_CRTL  0x38
#define SC7A20H_REG_CLICK_COEFF1  0x3A
#define SC7A20H_REG_CLICK_COEFF2  0x3B
#define SC7A20H_REG_CLICK_COEFF3  0x3C
#define SC7A20H_REG_TEMP_CFG    	0x1F
#define SC7A20H_REG_FIFO_DATA   	0x69
#define SC7A20H_REG_SOFT_RESET  	0x68
#define SC7A20H_REG_CHIP_ID  	0x0F

#define SC7A20H_REG_CTRL1       0x20 //ODR[3:0]; low power enable bit. Default value: 0;Z-axis;Y-axis;X-axis; enable, default value:1.
/*ODR3---ODR2---ODR1---ODR0---L---Z---Y---X*/
/* 0      0      0      0  /*Power Down*/
/* 0      0      0      1  /*1.56Hz*/
/* 0      0      1      0  /*12.5Hz*/
/* 0      0      1      1  /*25Hz*/
/* 0      1      0      0  /*50Hz*/
/* 0      1      0      1  /*100Hz*/
/* 0      1      1      0  /*200Hz*/
/* 0      1      1      1  /*400Hz*/
/* 1      0      0      0  /*800Hz*/
/* 1      0      0      1  /*1.48kHz*/
/* 1      0      1      0  /*2.66kHz*/
/* 1      0      1      0  /*4.434kHz
*/
#define SC7A20H_REG_CTRL2       0x21
/*XX---HDS----HPCF2----HPCF1----FDS----HP_RESET----HPIS2----HPIS1
HDS: High pass filter data source selection mode, Default value: 0. (0: Select the data after the operating mode; 1: Select the raw data of ADC output)
HPCF2-HPCF1: High pass cutoff frequency selection
HPCF---Ft[Hz]@12.5Hz---Ft[Hz]@25Hz---Ft[Hz]@50Hz---Ft[Hz]@100Hz---Ft[Hz]@200Hz---Ft[Hz]@400Hz
00        0.8             2             4             8              16             32
01        0.32            0.8           2             4              8              16
10        0.04            0.1           0.2           0.5            1              2
11        0.02            0.05          0.1           0.2            0.5            1
FDS: Data filtering selection,Default value: 0. (0: skip internal filtering; 1: data is output to data register or FIFO after filtering)
HP_RESET: High pass filter reset, Default value: 0. (0: reset is disabled; 1: reset is enabled)
HPIS2: Interrupt AOI2 high pass filtering enable. Default value: 0. (0: filtering disable; 1: filtering enable)
HPIS1: Interrupt AOI1 high pass filtering enable. Default value: 0. (0: filtering disable; 1: filtering enable)
*/
#define SC7A20H_REG_CTRL3       0x22
/*I1_CLICK---I1_AOI1---I1_AOI2---I1_DRDY---XX---I1_WTM---I1_OVERRUN---FIFO_MODE
I1_CLICK: CLICK interrupt on INT1. Default value:0. (0: disable; 1: enable)
I1_AOI1: AOI1 interrupt on INT1. Default value:0. (0: disable; 1: enable)
I1_AOI2: AOI2 interrupt on INT1. Default value:0. (0: disable; 1: enable)
I1_DRDY: DRDY interrupt on INT1. Default value:0. (0: disable; 1: enable)
I1_WTM: FIFO_WTM interrupt on INT1. Default value:0. (0: disable; 1: enable)
I1_OVERRUN: FIFO overflow interrupt on INT1. Default value:0. (0: disable; 1: enable)
FIFO_MODE: FIFO three-axis data read mode selection. Default value:0. (0: 12-bit mode; 1: 8-bit mode)
*/
#define SC7A20H_REG_CTRL4           0x23
#define SC7A20H_REG_CLICK_COEFF1    0x3A
#define SC7A20H_REG_CLICK_COEFF2    0x3B
#define SC7A20H_REG_CLICK_COEFF3    0x3C
/*continuous reading of triaxial data (register address 0x28 ~ 0x2D) is adopted, and the address of register data is 0xA8 (0x28|0x80)*/
#define SC7A20H_REG_OUTPUT          0x28
#define SC7A20H_MULTI_READ_FLG      0x80

#define SC7A20H_REG_CTRL1_50HZ		0x47/**0100 0111b, ODR=50Hz, Disable Low power mode, Enable X,Y,Z.*/
#define SC7A20H_REG_CTRL2_RESET		0x04/**0000 0100b, HP Reset.*/
#define SC7A20H_REG_CTRL3_INT1		0x80/**1000 0000b, INT1 Enabled.*/
#define SC7A20H_REG_CTRL4_BDU		0x80/**1000 0000b, 1: output is not updated until MSB and LSB are read.*/
#define SC7A20H_REG_CLICK_COEFF1_THRESHOLD    0x05 /**0000 0101b*/
#define SC7A20H_REG_CLICK_COEFF2_THRESHOLD    0x10 /**0001 0000b*/
#define SC7A20H_REG_CLICK_COEFF3_THRESHOLD    0x05 /**0000 0101b*/


#define SC7A20H_CHIP_ID				0x11

struct sc7a20x_config {
	struct i2c_dt_spec i2c;
};

typedef struct{
  int16_t x;
  int16_t y;
  int16_t z;
}sc7a20xRaw_t; 

int sc7a20x_init(const struct i2c_dt_spec *i2c);
#endif